public inbox for gdb-patches@sourceware.org
 help / color / mirror / Atom feed
* [COMMIT PATCH] get_prev_frame, UNWIND_NULL_ID -> UNWIND_OUTERMOST
@ 2013-11-28 18:26 Pedro Alves
  0 siblings, 0 replies; only message in thread
From: Pedro Alves @ 2013-11-28 18:26 UTC (permalink / raw)
  To: gdb-patches

- The UNWIND_NULL_ID check in get_prev_frame_1 used to really be
  against null_frame_id, back before we had outer_frame_id.  We didn't
  have UNWIND_OUTERMOST when outer_frame_id was added, but we do now,
  and it's more accurate.

- It used to be necessary to check for the sentinel frame explicitly
  because that uses null_frame_id for frame id.  Since no other frame
  can have that id nowadays (it's asserted by compute_frame_id), we
  don't need that explicit check.

Tested on x86_64 Fedora 17.

gdb/
2013-11-28  Pedro Alves  <palves@redhat.com>

	* frame.c (get_prev_frame_1): If the frame id is outer_frame_id,
	set the unwind stop reason to UNWIND_OUTERMOST, not
	UNWIND_NULL_ID.  Remove explicit check for sentinel frame.
---
 gdb/ChangeLog |  6 ++++++
 gdb/frame.c   | 11 +++++------
 2 files changed, 11 insertions(+), 6 deletions(-)

diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 33bd755..2076e5d 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,5 +1,11 @@
 2013-11-28  Pedro Alves  <palves@redhat.com>
 
+	* frame.c (get_prev_frame_1): If the frame id is outer_frame_id,
+	set the unwind stop reason to UNWIND_OUTERMOST, not
+	UNWIND_NULL_ID.  Remove explicit check for sentinel frame.
+
+2013-11-28  Pedro Alves  <palves@redhat.com>
+
 	* frame.c (frame_unwind_register): Say the register was "not
 	saved" instead of "optimized out".
 
diff --git a/gdb/frame.c b/gdb/frame.c
index ea06d51..32008ac 100644
--- a/gdb/frame.c
+++ b/gdb/frame.c
@@ -1773,19 +1773,18 @@ get_prev_frame_1 (struct frame_info *this_frame)
   if (this_frame->stop_reason != UNWIND_NO_REASON)
     return NULL;
 
-  /* Check that this frame's ID was valid.  If it wasn't, don't try to
-     unwind to the prev frame.  Be careful to not apply this test to
-     the sentinel frame.  */
+  /* Check that this frame is not the outermost.  If it is, don't try
+     to unwind to the prev frame.  */
   this_id = get_frame_id (this_frame);
-  if (this_frame->level >= 0 && frame_id_eq (this_id, outer_frame_id))
+  if (frame_id_eq (this_id, outer_frame_id))
     {
       if (frame_debug)
 	{
 	  fprintf_unfiltered (gdb_stdlog, "-> ");
 	  fprint_frame (gdb_stdlog, NULL);
-	  fprintf_unfiltered (gdb_stdlog, " // this ID is NULL }\n");
+	  fprintf_unfiltered (gdb_stdlog, " // frame ID is outer_frame_id }\n");
 	}
-      this_frame->stop_reason = UNWIND_NULL_ID;
+      this_frame->stop_reason = UNWIND_OUTERMOST;
       return NULL;
     }
 
-- 
1.7.11.7

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2013-11-28 17:38 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2013-11-28 18:26 [COMMIT PATCH] get_prev_frame, UNWIND_NULL_ID -> UNWIND_OUTERMOST Pedro Alves

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).